import 'package:flutter/material.dart';
import 'package:libui/async/async_loader.dart';

abstract class AsyncController with ChangeNotifier implements AsyncLoader {
  bool _ready = false;

  /// 防止页面销毁后,异步任务才完成,导致报错
  bool _disposed = false;

  bool ready() => _ready;

  complete() => _ready = true;

  @override
  void reset() {
    //reset ready so controller can be resuse by other
    _ready = false;
  }

  redraw() {
    if (!_disposed) {
      super.notifyListeners();
    }
  }

  @override
  notifyListeners() {
    if (!_disposed) {
      super.notifyListeners();
    }
  }

  @override
  void dispose() {
    _ready = false;
    _disposed = true;
    debugPrint('async controller dispose -->$runtimeType');
    super.dispose();
  }
}
