import 'dart:async';
import 'package:flutter/material.dart';
import 'package:libui/async/async_controller.dart';
import 'package:libui/i18n/i18n_model.dart';
import 'package:libui/i18n/i18n_delegate.dart';

//https://www.oracle.com/technical-resources/articles/javase/locale.html
const Locales = [
  'en_US',
  'en_CA',
  'en_GB',
  'en_AU',
  'zh_CN',
  'zh_TW',
  'zh_TW',
  'zh_TW',
  'zh_TW',
  'ja_JP',
  'it_IT',
  'de_DE',
];

bool isSupportedLocale(Locale locale) {
  var id = localeToId(locale);
  var result = Locales.contains(id);
  return result;
}

String localeToId(Locale locale) {
  return '${locale.languageCode}_${locale.countryCode}';
}

Locale idToLocale(String id) {
  var ids = id.split('_');
  if (ids.length > 1) return Locale(ids[0], ids[1]);
  return Locale(ids[0]);
}

class I18nController extends AsyncController {
  static I18nController current;

  final I18nModel model;

  String pageName;

  I18nController(this.model) {}

  List<String> get locales => Locales;

  String get currentLocale => I18nDelegate.localeId;

  static currentPage(I18nController controller, String pageName) {
    current = controller;
    current.pageName = pageName;
  }

  static I18nController of(BuildContext context) {
    return Localizations.of<I18nController>(context, I18nController);
  }

  Future<void> setPageName(String name) async {
    pageName = name;
  }

  @override
  Future<void> load(BuildContext context) async {
    //if (I18nDelegate.localeId != null && pageName != null) {
    await model.load(I18nDelegate.localeId, pageName);
    complete();
    //}
  }

  static String T(String key) {
    if (current == null) {
      return '';
    }
    return current.model.localization[key] ?? '!!! $key not found';
  }

  //  operator [](String key) => model.localization[key] ?? '!!! $key not found';
}
